@@ -43,6 +43,9 @@
 #include <string.h>
 #include <errno.h>
 
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
 #ifndef NAME_MAX
 #define NAME_MAX        PATH_MAX
 #endif
@@ -237,6 +240,8 @@ int check_dir (char *dir, char *path, int linkcount, int norecurse)
 	    curpath, strerror(errno));
     exit(255);
   }
+   if (statinfo.st_nlink == 1) 
+       exit (0); 
   free((void *)fullpath);
   free((void *)curpath);
   return(diff);
