@@ -7,6 +7,7 @@
    22527 Hamburg
    Germany
 
+   01/0224 - GCC 15 fixes
    02/20/97 - Minimal changes for Linux/FreeBSD port.
    02/25/97 - Another little bit change
    12/26/98 - New Red Hat compatibility
@@ -51,7 +52,7 @@ int main () { return 0; }
 #include <lastlog.h>
 #endif
 #include <sys/file.h>
-#ifdef SOLARIS2
+#if defined (SOLARIS2) || defined (linux)
 #include <fcntl.h>
 #endif
 
@@ -77,7 +78,7 @@ int main () { return 0; }
 long total_wtmp_bytes_read=0;
 size_t wtmp_file_size;
 uid_t *uid;
-void read_status();
+void read_status(int signum);
 
 struct s_localpwd {
      int numentries;
@@ -109,8 +110,10 @@ int main(int argc, char*argv[]) {
 	uid_t		*uid;
         char wtmpfile[128], lastlogfile[128];
 
-        memcpy(wtmpfile, WTMP_FILENAME, 127);
-        memcpy(lastlogfile, LASTLOG_FILENAME, 127);
+        memset(wtmpfile, '\0', 128);
+        memset(lastlogfile, '\0', 128);
+        strncpy(wtmpfile, WTMP_FILENAME, 127);
+        strncpy(lastlogfile, LASTLOG_FILENAME, 127);
 
         while (--argc && ++argv) /* poor man getopt */
         {
@@ -213,7 +216,7 @@ int nonuser(struct utmp utmp_ent)
 }
 #endif
 
-void read_status() {
+void read_status(int signum) {
    double remaining_time;
    static long last_total_bytes_read=0;
    int diff;
