@@ -30,7 +30,8 @@ int main () { return 0; }
 #include <time.h>
 #include <sys/time.h>
 #include <sys/file.h>
-#ifdef SOLARIS2
+#include <fcntl.h>
+#if defined (SOLARIS2) || defined (linux) 
 #include <fcntl.h>
 #endif
 
@@ -70,7 +71,7 @@ int main(int argc, char*argv[]) {
 	gettimeofday(&mytime, &dummy);
        act_time=mytime.tv_sec;
        wtmpfile[127]='\0';
-       memcpy(wtmpfile, WTMP_FILENAME, 127);
+       strncpy(wtmpfile, WTMP_FILENAME, 127);
        if ( argc == 3 && !memcmp("-f", argv[1], 2) && *argv[2])
           memcpy(wtmpfile, argv[2], 127);
 
